pub struct ErrorResponse {
pub code: String,
pub reason: String,
pub remediation: String,
}Expand description
ErrorResponse : All Naurt errors come in this standard format. code is a unique error code you can quote to support, should you need to reason explains why this error has been received remediation gives steps to help resolve this error
Fields
code: Stringreason: Stringremediation: StringImplementations
Sourceimpl ErrorResponse
impl ErrorResponse
Sourcepub fn new(code: String, reason: String, remediation: String) -> ErrorResponse
pub fn new(code: String, reason: String, remediation: String) -> ErrorResponse
All Naurt errors come in this standard format. code is a unique error code you can quote to support, should you need to reason explains why this error has been received remediation gives steps to help resolve this error