pub enum FinalDestinationMatchLevel {
Unit,
StreetNumber,
Street,
Postalcode,
}Expand description
FinalDestinationMatchLevel : Match level describing the geographical level to which an address has been matched. It can be one of the following: - Unit - StreetNumber - Street - Postalcode See: http://localhost:4321/reference/search-confidence/ Match level describing the geographical level to which an address has been matched. It can be one of the following: - Unit - StreetNumber - Street - Postalcode See: http://localhost:4321/reference/search-confidence/
Variants