FinalDestinationStatus

Enum FinalDestinationStatus 

pub enum FinalDestinationStatus {
    Ok,
    NoMatches,
}
FinalDestinationStatus : The queries and responses arrays are always 1:1. If no match can be found, a 404 will NOT be returned. Instead, check this enum for no_matches. That indicates no error has happened, but nothing was found. ok when something is found. The queries and responses arrays are always 1:1. If no match can be found, a 404 will NOT be returned. Instead, check this enum for no_matches. That indicates no error has happened, but nothing was found. ok when something is found.

Variants



Ok



NoMatches